@@ -1,6 +1,7 @@
 import itertools
 import random
 from typing import (
+    TYPE_CHECKING,
     Any,
     Dict,
     Iterable,
@@ -16,8 +17,11 @@ from necessary import necessary
 
 from ..base import BatchedBaseMapper, SingleBaseMapper, TransformElementType
 
-with necessary('transformers', soft=True):
-    from transformers.tokenization_utils_base import PreTrainedTokenizerBase
+with necessary("transformers", soft=True) as TRANSFORMERS_AVAILABLE:
+    if TRANSFORMERS_AVAILABLE or TYPE_CHECKING:
+        from transformers.tokenization_utils_base import (
+            PreTrainedTokenizerBase,
+        )
 
 
 class TokensSequencesPaddingMapper(SingleBaseMapper):
@@ -27,7 +31,7 @@ class TokensSequencesPaddingMapper(SingleBaseMapper):
 
     def __init__(
         self,
-        tokenizer: 'PreTrainedTokenizerBase',
+        tokenizer: "PreTrainedTokenizerBase",
         input_field: str = "input_ids",
     ) -> None:
         """Mapper that add BOS/SEP/EOS sequences of tokens.
@@ -45,7 +49,7 @@ class TokensSequencesPaddingMapper(SingleBaseMapper):
 
     @staticmethod
     def _find_special_token_ids(
-        tokenizer: 'PreTrainedTokenizerBase',
+        tokenizer: "PreTrainedTokenizerBase",
     ) -> Tuple[List[int], List[int], List[int]]:
         """By default, tokenizers only know how to concatenate 2 fields
         as input; However, for our purposes, we might care about more than
@@ -102,7 +106,7 @@ class TokensSequencesPaddingMapper(SingleBaseMapper):
 class AttentionMaskSequencePaddingMapper(TokensSequencesPaddingMapper):
     def __init__(
         self,
-        tokenizer: 'PreTrainedTokenizerBase',
+        tokenizer: "PreTrainedTokenizerBase",
         input_field: str = "attention_mask",
     ) -> None:
         """Mapper to add BOS/SEP/EOS tokens to an attention mask sequence.
@@ -124,7 +128,7 @@ class AttentionMaskSequencePaddingMapper(TokensSequencesPaddingMapper):
 class TokenTypeIdsSequencePaddingMapper(TokensSequencesPaddingMapper):
     def __init__(
         self,
-        tokenizer: 'PreTrainedTokenizerBase',
+        tokenizer: "PreTrainedTokenizerBase",
         input_field: str = "token_type_ids",
     ) -> None:
         """Mapper to add BOS/SEP/EOS tokens to a token type ids sequence.
@@ -234,7 +238,6 @@ class LabelsMaskerMapper(BatchedBaseMapper):
     def transform(
         self, data: Iterable[TransformElementType]
     ) -> Iterable[TransformElementType]:
-
         if self.strategy == "all":
             # there's no masking to do if the strategy is all!
             # `all` is provided for convenience, but it's not really a
@@ -252,7 +255,6 @@ class LabelsMaskerMapper(BatchedBaseMapper):
                 # n sequences with m active labels into n * m sequences
                 # with only one active label.
                 for i, _ in enumerate(labels):
-
                     # new labels sequence here
                     new_labels = [
                         l if i == j else self.label_mask_id
@@ -298,7 +300,7 @@ class MultiSequenceStriderMapper(BatchedBaseMapper):
         fields_to_stride: Optional[List[str]] = None,
         max_length: Optional[int] = None,
         extra_length_per_seq: Optional[int] = None,
-        tokenizer: Optional['PreTrainedTokenizerBase'] = None,
+        tokenizer: Optional["PreTrainedTokenizerBase"] = None,
         max_step: Optional[int] = None,
     ) -> None:
         """Mapper to create multiple subset sequences from a single sequence
@@ -372,7 +374,6 @@ class MultiSequenceStriderMapper(BatchedBaseMapper):
     def transform(
         self, data: Iterable[TransformElementType]
     ) -> Iterable[TransformElementType]:
-
         ref_field_name, *_ = self.input_fields
 
         for sample in data:
@@ -399,7 +400,6 @@ class MultiSequenceStriderMapper(BatchedBaseMapper):
                 ) >= self.max_stride_count
 
                 if stride_too_long or stride_has_too_many_seqs:
-
                     yield {
                         k: (
                             # if a list of fields to strides has been provided,
@@ -490,7 +490,6 @@ class SingleValueToSequenceMapper(SingleBaseMapper):
     def _make_sequence_from_value(
         self, value: Union[int, float], like_seq: Sequence[Any]
     ) -> Sequence[Union[int, float]]:
-
         if self.strategy == "first":
             return [value] + [
                 self.padding_id for _ in range(len(like_seq) - 1)
@@ -515,7 +514,6 @@ class SingleValueToSequenceMapper(SingleBaseMapper):
 
 
 class SequencesConcatenateMapper(SingleBaseMapper):
-
     concat_fields: Union[Dict[str, None], None]
 
     def __init__(self, concat_fields: Optional[List[str]] = None):
